local gtt = GameTooltip;

-- Variables
local ttm = CreateFrame("Frame","TipTacMSP");
local current = {};

-- Allow these to be accessed externally from other addons
ttm.current = current;

ttm:Hide();

--------------------------------------------------------------------------------------------------------
--                                           Gather MSP
--------------------------------------------------------------------------------------------------------

local function GatherMSP(field)
	if _G.msp ~= nil then
		playername = current.name;
		_G.msp.Request(playername, field);
		if (_G.msp.char[playername] ~= nil) then
			if (_G.msp.char[playername].field[field] ~= "") then
				return _G.msp.char[playername].field[field]
			end
		end
		return nil
	else
		return "No MSP-Compatible Addon found"
	end
end

function TipTacMSPFindConfigWindowAndAddOwnConfig()
	-- "Workaround" to add the Options to the TipTac-Options-Menu
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPState", label = "Show MSP Status", tip = "Shows the MSP Status in the Game Tooltip."};
	TipTacOptions.options[2][#TipTacOptions.options[2] + 1] =
		{ type = "Check", var = "showMSPName", label = "Show MSP Name", tip = "Shows the MSP Name in the Game Tooltip.", y = 16};
	
	-- Set Defaults in this "Workaround"
	if (TipTac_Config["showMSPState"] == nil) then
		print("TipTacMSP-Status Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config["showMSPState"] = true;
	end
	if (TipTac_Config["showMSPName"] == nil) then
		print("TipTacMSP-Name Settings set to Default. To change, go to the TipTac-Options to the 'Special' page.");
		TipTac_Config["showMSPName"] = true;
	end
end

gtt:HookScript("OnTooltipSetUnit",function(self,...)
	-- Get the unit -- Check the UnitFrame unit if this tip is from a concated unit, such as "targettarget".
	local _, unit = self:GetUnit();
	if (not unit) then
		local mFocus = GetMouseFocus();
		if (mFocus) and (mFocus.unit) then
			unit = mFocus.unit;
		end
	end
	
	-- No Unit or not a Player
	if (not unit) or (not UnitIsPlayer(unit)) then
		return;
	end
	
	-- Wipe Current Record
	wipe(current);
	current.unit = unit;
	current.name = UnitName(unit);
	current.guid = UnitGUID(unit);
	
	if (TipTac_Config["showMSPState"]) then
		current.msp_va = GatherMSP("VA");
		if (current.msp_va ~= nil) then
			self:AddLine("MSP-Status: "..current.msp_va);
		end
	end
	if (TipTac_Config["showMSPName"]) then
		current.msp_na = GatherMSP("NA");
		if ((current.msp_na ~= nil) and (current.msp_na ~= current.name)) then
			self:AddLine("MSP-Name: "..current.msp_na);
		end
	end
end);

TipTacMSPFindConfigWindowAndAddOwnConfig();